@@ -89,6 +89,9 @@ pub struct PackageJson {
     pub package_manager: Option<String>,
 
     pub workspaces: Option<Workspaces>,
+
+    #[serde(rename = "cacheDirectories")]
+    pub cache_directories: Option<Vec<String>>,
 }
 
 #[derive(Default, Debug)]
@@ -171,6 +174,12 @@ impl Provider for NodeProvider {
 
         // Node modules cache directory
         build.add_cache_directory((*NODE_MODULES_CACHE_DIR).to_string());
+        let package_json: PackageJson = app.read_json("package.json").unwrap_or_default();
+        if let Some(cache_directories) = package_json.cache_directories {
+            for dir in cache_directories {
+                build.add_cache_directory(dir);
+            }
+        }
 
         NodeProvider::cache_tsbuildinfo_file(app, &mut build);
 
@@ -537,23 +546,29 @@ impl NodeProvider {
                 &ts_config.compiler_options.unwrap_or_default(),
             ));
         }
+
         if let Some(compiler_options) = ts_config.compiler_options {
             if let Some(incremental) = compiler_options.incremental {
                 // if incremental is enabled
                 if incremental {
-                    if let Some(ts_build_info_file) = compiler_options.ts_build_info_file {
-                        // if config file is explicitly provided
-                        build.add_cache_directory(ts_build_info_file);
-                    } else if let Some(out_dir) = compiler_options.out_dir {
-                        // if it is not provided but outdir is, use that
-                        build.add_cache_directory(format!("{out_dir}/tsconfig.tsbuildinfo"));
-                    } else {
-                        // if not out dir is set
-                        build.add_cache_directory("tsconfig.tsbuildinfo");
+                    let tsbuildinfo =
+                        if let Some(ts_build_info_file) = compiler_options.ts_build_info_file {
+                            // if config file is explicitly provided
+                            ts_build_info_file
+                        } else if let Some(out_dir) = compiler_options.out_dir {
+                            // if it is not provided but outdir is, use that
+                            format!("{out_dir}/tsconfig.tsbuildinfo")
+                        } else {
+                            // if not out dir is set
+                            "tsconfig.tsbuildinfo".to_string()
+                        };
+
+                    if app.includes_file(tsbuildinfo.as_str()) {
+                        build.add_cache_directory(tsbuildinfo);
                     }
                 }
             }
-        }
+        };
     }
 }
 
